@@ -13,7 +13,7 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use Carp qw/cluck/;
 
-our $VERSION  = 0.98;
+our $VERSION  = 0.99;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -31,6 +31,7 @@ sub run {
         'tag|t=s',
         'branch|b=s',
         'local|l!',
+        'remote|r!',
         'format|f=s',
         'quick|q!',
         'include|i=s',
@@ -155,7 +156,7 @@ sub do_update_me {
 
 sub branches_contain {
     my @releases = @_;
-    my @branches = $workflow->branches('both');
+    my @branches = $workflow->branches($option{remote} ? 'remote' : 'both');
     my $format = q/--format=format:%at <%an>%ae/;
     my @csv;
 
@@ -305,7 +306,7 @@ git-up-to-date - Check that git branches include latest production branch/tag
 
 =head1 VERSION
 
-This documentation refers to git-up-to-date version 0.98
+This documentation refers to git-up-to-date version 0.99
 
 =head1 SYNOPSIS
 
