@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.98;
+our $VERSION  = 0.99;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -44,8 +44,11 @@ sub run {
 
     # do stuff here
     my $action = @ARGV && $actions{$ARGV[0]} ? shift @ARGV : @ARGV ? 'do' : 'show';
-    my $once   = $option{once} ? -1 : -$option{runs} || 1;
     my ($last) = git_state();
+    my $once
+        = $option{once} ? -1
+        : $option{runs} ? -$option{runs}
+        :                 1;
 
     while ($once) {
         eval {
@@ -173,7 +176,7 @@ git-watch - Watch for changes in repository up-stream
 
 =head1 VERSION
 
-This documentation refers to git-watch version 0.98
+This documentation refers to git-watch version 0.99
 
 =head1 SYNOPSIS
 
